<?php
$lang['addedit_billingform_template'] = 'Adicionar/Editar formul&aacute;rio modelo Fatura&ccedil;&atilde;o ';
$lang['addedit_completion_template'] = 'Adicionar/Editar Modelo Conclus&atilde;o';
$lang['addedit_confirmorder_template'] = 'Adicionar/Editar Modelo Pedidos Confirma&ccedil;&atilde;o ';
$lang['addedit_gateway_complete_template'] = 'Adicionar/Editar modelo Gateway completo';
$lang['addedit_invoice_template'] = 'Adicionar/Editar Modelo Factura';
$lang['addedit_paymentform_template'] = 'Adicionar/Editar Formul&aacute;rio de Pagamento Template';
$lang['address1'] = 'Endere&ccedil;o Linha 1';
$lang['address2'] = 'Endere&ccedil;o Linha 2';
$lang['add_msg_template'] = 'Adicionar Template para Nova Mensagem  ';
$lang['admin_email_addresses'] = 'Lista separada por v&iacute;rgulas dos E-mails para o admin, quando uma novo pedido &eacute; submetido';
$lang['admin_email_template'] = 'Email Template Admin';
$lang['any'] = 'Qualquer';
$lang['ask_delete'] = 'Tem certeza de que deseja excluir este item?';
$lang['ask_delete_order'] = 'Tem certeza de que deseja excluir este pedido. N&atilde;o &eacute; normalmente recomendado apagar pedidos?';
$lang['ask_edit_billing'] = 'Tem certeza de que pretende modificar as informa&ccedil;&otilde;es de fatura&ccedil;&atilde;o para este pedido, conforme especificado acima?';
$lang['back'] = 'Voltar';
$lang['back_to_orders'] = 'Voltar para os Pedidos';
$lang['backorder'] = 'Voltar para o Pedido';
$lang['bill_to'] = 'Fatura&ccedil;&atilde;o Para';
$lang['billing_address'] = 'Endere&ccedil;o para a Fatura&ccedil;&atilde;o';
$lang['billing_form_templates'] = 'Fatura&ccedil;&atilde;o Form Templates';
$lang['billing_info'] = 'Informa&ccedil;&atilde;o Fatura&ccedil;&atilde;o';
$lang['body'] = 'Corpo de mensagem';
$lang['cancel'] = 'Cancelar';
$lang['cancelled'] = 'Cancelada';
$lang['captcha_title'] = 'Texto Captcha';
$lang['cart_module'] = 'Carrinho M&oacute;dulo';
$lang['cart_settings'] = 'Carrinho Cofigura&ccedil;&otilde;es';
$lang['cc_AMEX'] = 'American Express ';
$lang['cc_Discover'] = 'Discover ';
$lang['cc_MasterCard'] = 'Mastercard ';
$lang['cc_Visa'] = 'Visa ';
$lang['city'] = 'Cidade';
$lang['completed'] = 'Completo';
$lang['completion_templates'] = 'Templates Conclus&atilde;o';
$lang['confirmed'] = 'Confirmado';
$lang['confirm_order'] = 'Confirme o Seu Pedido';
$lang['confirmation_form_templates'] = 'Confirma&ccedil;&atilde;o Form Templates';
$lang['confirmation_num'] = 'N&uacute;mero de Confirma&ccedil;&atilde;o';
$lang['country'] = 'Pa&iacute;s';
$lang['created'] = 'Criado';
$lang['create_invoice'] = 'Criar fatura para este pedido';
$lang['create_invoice_for'] = 'Criar fatura para o pedido %s';
$lang['creditcard_expiry'] = 'CreditCard Data de Expira&ccedil;&atilde;o';
$lang['creditcard_number'] = 'CreditCard N&uacute;mero';
$lang['creditcard_type'] = 'CreditCard Tipo';
$lang['creditcard_verifycode'] = 'Verification C&oacute;dico';
$lang['customer_name'] = 'Cliente Nome';
$lang['dflt_billingform_template'] = 'Formul&aacute;rio Template Padr&atilde;o para Factura&ccedil;&atilde;o ';
$lang['dflt_confirmorder_template'] = 'Template Padr&atilde;o do formul&aacute;rio de confirma&ccedil;&atilde;o';
$lang['dflt_completion_template'] = 'Template Conclus&atilde;o Padr&atilde;o';
$lang['dflt_gateway_complete_template'] = 'Default &quot;Portal transac&ccedil;&atilde;o conclu&iacute;da&quot; template';
$lang['dflt_invoice_message'] = 'Obrigado por comprar com {sitename}.';
$lang['dflt_invoice_template'] = 'Template Padr&atilde;o Factura&ccedil;&atilde;o';
$lang['dflt_paymentform_template'] = 'Formul&aacute;rio Template Padr&atilde;o para Pagamentos';
$lang['default_templates'] = 'Template Padr&atilde;o';
$lang['delete'] = 'Eliminar';
$lang['description'] = 'Descri&ccedil;&atilde;o';
$lang['destinations'] = 'Destino';
$lang['details'] = 'Detalhes';
$lang['edit'] = 'Editar';
$lang['edit_billing_info'] = 'Editar informa&ccedil;&otilde;es de fatura&ccedil;&atilde;o';
$lang['email'] = 'Email ';
$lang['email_address'] = 'Endere&ccedil;o de Email';
$lang['email_invoice'] = 'E-mail esta factura ao cliente e admins autorizados';
$lang['email_sent_to'] = 'Email Enviado para';
$lang['email_subject'] = 'Assunto Email ';
$lang['error_badcaptcha'] = 'O valor do captcha fornecido est&aacute; incorrecto';
$lang['error_insufficientparams'] = 'Um par&acirc;metro obrigat&oacute;rio est&aacute; em falta';
$lang['error_invalidfield'] = 'Os seguintes campos est&atilde;o inv&aacute;lidos: %s';
$lang['error_missingshippinginfo'] = 'S&atilde;o Insuficientes as informa&ccedil;&otilde;es fornecidas';
$lang['error_namexists'] = 'Um item com esse nome j&aacute; existe';
$lang['error_nocartmodule'] = 'N&atilde;o foi poss&iacute;vel encontrar o m&oacute;dulo Carrinho';
$lang['error_noemailaddress'] = 'Nenhum endere&ccedil;o de e-mail foi associado a este userid';
$lang['error_nofeumodule'] = 'N&atilde;o foi poss&iacute;vel encontrar o m&oacute;dulo FrontEndUsers';
$lang['error_nopaymentgateway'] = 'Nenhum gateway de pagamento especificado';
$lang['error_noproductsmodule'] = 'N&atilde;o foi poss&iacute;vel localizar o m&oacute;dulo Produtos';
$lang['error_notloggedin'] = 'O utilizador n&atilde;o se encontra logado';
$lang['error_orderinvalid'] = 'Existe um problema com este pedido (a informa&ccedil;&atilde;o &eacute; inconsistente)';
$lang['error_ordernotfound'] = 'O Pedido solicitado n&atilde;o foi encontrado';
$lang['error_permissiondenied'] = 'Permis&atilde;o Negada';
$lang['error_unknownstatus'] = 'Recebeu um estado desconhecido a partir do gateway de pagamento ';
$lang['error_usernotingroup'] = 'O utilizador actual logado n&atilde;o &eacute; um membro do grupo exigido';
$lang['fax'] = 'Fax ';
$lang['filter'] = 'Filtro';
$lang['first_name'] = 'Primeiro Nome';
$lang['firstpage'] = '<< ';
$lang['friendlyname'] = 'Gest&atilde;o de Pedidos';
$lang['from'] = 'De';
$lang['gateway_module'] = 'M&oacute;dulo Gateway de Pagamento ';
$lang['gateway_complete_templates'] = 'Templates Gateway Conclus&atilde;o';
$lang['gateway_failure_message'] = 'Sua transac&ccedil;&atilde;o n&atilde;o foi conclu&iacute;da. Ou a opera&ccedil;&atilde;o foi cancelada ou algum outro erro ocorreu. Por favor, confirme as suas informa&ccedil;&otilde;es de pagamento e tente novamente. O Seu carrinho foi esvaziado para sua seguran&ccedil;a e comodidade. Obrigado pelo seu tempo';
$lang['general_settings'] = 'Configura&ccedil;&otilde;es Gerais';
$lang['help_param_nocaptcha'] = 'Se este par&acirc;metro for definido, o captcha ser&aacute; desligado';
$lang['help_param_template'] = 'Especificar um template n&atilde;o padr&atilde;o a ser usado nesta ac&ccedil;&atilde;o padr&atilde;o';
$lang['hold'] = 'Segurar';
$lang['html'] = 'HTML ';
$lang['html_email'] = 'Enviar um Email em HTML';
$lang['id'] = 'Id ';
$lang['incomplete'] = 'Incompleto (parcialmente transferidos)';
$lang['info_admin_invoice_template'] = 'Escolha um template que ser&aacute; utilizado para a impress&atilde;o da factura (janela)  quando gere um pedido';
$lang['info_adminemail_template'] = 'Este template controla o layout e conte&uacute;do dos e-mails que s&atilde;o enviados para o administrador autorizado quando uma novo pedido &eacute; submetido';
$lang['info_allow_creditcard_entry'] = '<strong>Nota:</strong>Estas informa&ccedil;&otilde;es ser&atilde;o armazenadas na base de dados. <br /> Apesar da encripta&ccedil;&atilde;o usada para armazenar dados privados, <br /> recomenda-se a n&atilde;o usar esta op&ccedil;&atilde;o. <br/ > Em vez disso, use um m&oacute;dulo  gateway de pagamento compat&iacute;vel .';
$lang['info_billingpage'] = '<strong> Observa&ccedil;&atilde;o: </strong> Essa prefer&ecirc;ncia, bem como as outras  s&atilde;o utilizadas para permitir que o administrador possa utilizar diferentes p&aacute;ginas CMSMS  para os diferentes formul&aacute;rios. Se a op&ccedil;&atilde;o &quot;Nenhuma&quot; for especificado, ent&atilde;o a p&aacute;gina actual ser&aacute; usada.';
$lang['info_default_templates'] = 'Este formul&aacute;rio controla o conte&uacute;do do template quando clicar em &quot;Novo Template&quot; no &quot;Formul&aacute;rio de Confirma&ccedil;&atilde;o Template&#039;. Editando o texto aqui n&atilde;o ter&aacute; efeitos imediatos sobre a apar&ecirc;ncia do seu site';
$lang['info_encryption_key'] = 'Esta chave &eacute; gerada aleatoriamente quando o m&oacute;dulo &eacute; instalado. Tenha cuidado ao alterar este valor se j&aacute; existem encomendas no sistema.';
$lang['info_invoicepage'] = '<strong> Observa&ccedil;&atilde;o: </strong> Essa p&aacute;gina tamb&eacute;m &eacute; usada para sucesso e erro no sistema de pagamento';
$lang['info_order_notes'] = 'Forne&ccedil;a algumas notas especiais para este pedido';
$lang['info_skip_invoice_page'] = 'Quando permitindo aos usu&aacute;rios especificar informa&ccedil;&otilde;es de pagamento, <br/> eles devem proceder &agrave; p&aacute;gina da factura , <br/> ou directamente para a transac&ccedil;&atilde;o de conclus&atilde;o?';
$lang['info_useremail_template'] = 'Este template controla o layout e conte&uacute;do do e-mail que &eacute; enviado para o utilizador quando uma novo pedido &eacute; submetido';
$lang['info_use_integer'] = 'Use apenas valores inteiros';
$lang['interval_oneday'] = 'Um  Dia';
$lang['interval_onemonth'] = 'Um Mes';
$lang['interval_onequarter'] = 'Um Trimestre';
$lang['interval_oneweek'] = 'Uma Semana';
$lang['interval_oneyear'] = 'Um Ano';
$lang['interval_twoweeks'] = 'Duas Semanas';
$lang['invoice'] = 'Factura';
$lang['invoiced'] = 'Facturado';
$lang['invoice_settings'] = 'Defini&ccedil;&otilde;es Factura ';
$lang['invoice_templates'] = 'Templates Facturas';
$lang['items'] = 'Items ';
$lang['last_name'] = '&Uacute;ltimo Nome';
$lang['last_modified'] = '&Uacute;ltima modifica&ccedil;&atilde;o';
$lang['lastpage'] = ' >>';
$lang['message'] = 'Mesagem';
$lang['message_templates'] = 'Mesagem Templates';
$lang['moddescription'] = 'Processador de Pedidos';
$lang['modified'] = 'Modificado';
$lang['name'] = 'Nome';
$lang['new_order_submitted'] = 'Um novo pedido fou submetido';
$lang['next'] = 'Pr&oacute;ximo';
$lang['nextpage'] = ' >';
$lang['no'] = 'N&atilde;o';
$lang['no_items_in_cart'] = 'Sem Items no seu Carrinho.  Por favor, adicione alguns antes de tentar realizar o checkout.';
$lang['none'] = 'Nenhum';
$lang['notcancelledshipped'] = 'Qualquer, mas Cancelado ou Comercializado';
$lang['notshipped'] = 'N&atilde;o Comercializado';
$lang['num'] = 'N&ordm;.';
$lang['order'] = 'Pedido';
$lang['orders'] = 'Pedidos';
$lang['order_confirm_form_templates'] = 'Templates Confirma&ccedil;&atilde;o  Encomenda';
$lang['order_details'] = 'Detalhes do Pedido';
$lang['order_notes'] = 'Pedido Notas';
$lang['order_number'] = 'Pedido N&ordm;.';
$lang['order_processing'] = 'Pedido Processamento';
$lang['order_statistics'] = 'Pedido Estatisticas';
$lang['order_summary'] = 'Pedido Sum&aacute;rio';
$lang['paid'] = 'Pago';
$lang['payment_form_templates'] = 'Pagamento Form Templates';
$lang['payment_gateway_settings'] = 'Configra&ccedil;&otilde;es Pagamento Gateway ';
$lang['payment_info'] = 'Informa&ccedil;&atilde;o de Pagamento';
$lang['phone'] = 'Telefone';
$lang['popup_new_window'] = 'Factura em uma nova janela popup';
$lang['postinstall'] = 'O m&oacute;dulo Pedidos foi instalado com &ecirc;xito';
$lang['postuninstall'] = 'O m&oacute;dulo Pedidos e todos os dados associados foram removidos';
$lang['post_order_msg'] = 'Escreva uma mesagem no Pedido';
$lang['postal'] = 'C&oacute;digo Postal';
$lang['preferences'] = 'Perfer&ecirc;ncias';
$lang['prevpage'] = '< ';
$lang['price'] = 'Pre&ccedil;o';
$lang['print_invoice'] = 'Imprima esta fatura';
$lang['procede_manual_checkout'] = 'Prosseguir Compra manual ';
$lang['process_order'] = 'Processo de Pedidos';
$lang['product_id'] = 'Produto ID';
$lang['prompt_admin_invoice_template'] = 'Vers&atilde;o de Impress&atilde;o do Template Factura';
$lang['prompt_allow_creditcard_entry'] = 'Permitir ao cliente inserir informa&ccedil;&otilde;es de cart&atilde;o de cr&eacute;dito';
$lang['prompt_billingpage'] = 'P&aacute;gina para assumir que a fatura&ccedil;&atilde;o ser&aacute; exibida no formul&aacute;rio. Esta &eacute; geralmente a p&aacute;gina com o seu  <code>{Orders}</code> tag.';
$lang['prompt_confirmpage'] = 'P&aacute;gina para usar o formul&aacute;rio de confirma&ccedil;&atilde;o';
$lang['prompt_date_search_type'] = 'Filtrar Registos que foram';
$lang['prompt_encryption_key'] = 'Encripta&ccedil;&atilde;o chave';
$lang['prompt_forcessl'] = 'Redirecionar a p&aacute;gina para HTTPS na entrada de informa&ccedil;&otilde;es de pagamento';
$lang['prompt_invoice_message'] = 'Mensagem aparecer no topo de todas as facturas';
$lang['prompt_invoicepage'] = 'P&aacute;gina a usar para exibir a factura';
$lang['prompt_of'] = 'De';
$lang['prompt_ordernum_prefix'] = 'PedidoNum Prefixo';
$lang['prompt_page'] = 'P&aacute;gina';
$lang['prompt_pagelimit'] = 'N&uacute;mero de pedidos por p&aacute;gina';
$lang['prompt_paymentpage'] = 'P&aacute;gina  utilizada para o formul&aacute;rio de pagamento ';
$lang['prompt_permit_deletion'] = 'Permitir eliminar pedidos';
$lang['prompt_skip_invoice_page'] = 'Saltar P&aacute;gina Factura ';
$lang['prompt_template'] = 'Template Mensagens';
$lang['proposed'] = 'Prosposto';
$lang['quantity'] = 'Quantidade';
$lang['really_uninstall'] = 'Tem certeza de que deseja proceder esta ac&ccedil;&atilde;o? Todos os dados associados a este m&oacute;dulo ser&atilde;o perdidos se continuar';
$lang['records_matching_query'] = 'N&uacute;mero de registos que correspondem &agrave; sua consulta';
$lang['regex'] = 'Express&otilde;es Regulares';
$lang['return'] = 'Retorno';
$lang['require_group_membership'] = 'Exigir&aacute; que todos os utilizadores que processem um Pedido sejam um membro do grupo FEU';
$lang['select_action'] = 'Seleccionar Ac&ccedil;&atilde;o';
$lang['select_one'] = 'Seleccione Um';
$lang['select_invoice_template'] = 'Seleccionar Factura Template';
$lang['send'] = 'Enviar';
$lang['send_message'] = 'Enviar a Este Cliente uma Mensagem';
$lang['sent'] = 'Enviar';
$lang['ship_to'] = 'Entrega Para';
$lang['shipped'] = 'Entregue';
$lang['shipping'] = 'Transporte';
$lang['shipping_address'] = 'Endere&ccedil;o de Entrega';
$lang['shipping_info'] = 'Informa&ccedil;&atilde;o de Entrega';
$lang['shipping_info_if_different'] = 'Informa&ccedil;&atilde;o de Entrega <em>(&Eacute; diferente da informa&ccedil;&atilde;o da Factura&ccedil;&atilde;o)</em>';
$lang['shipping_message'] = 'Mesagem relaccionada neste destino';
$lang['shipping_module'] = 'Transporte M&oacute;dulo';
$lang['shipping_settings'] = 'Transporte Cofigura&ccedil;&atilde;o';
$lang['shipping_total'] = 'Total de Compras';
$lang['special_instructions'] = ' Instru&ccedil;&otilde;es Especiais';
$lang['state/province'] = 'Distrito';
$lang['status'] = 'Estado';
$lang['subject'] = 'Assunto';
$lang['submit'] = 'Submeter';
$lang['submitted'] = 'Submetido';
$lang['submit_payment_info'] = 'Submeter informa&ccedil;&otilde;es de pagamento';
$lang['subtotal'] = 'Sub total';
$lang['tax'] = 'Tribut&aacute;rio';
$lang['tax_module'] = 'M&oacute;dulo Impostos';
$lang['tax_settings'] = ' Impostos Configura&ccedil;&atilde;o';
$lang['template'] = 'Template ';
$lang['template_name'] = 'Template Nome';
$lang['thank_you_for_order'] = 'Obrigado pela sua compra na {sitename}';
$lang['title_adminemail_template'] = 'Admin Email Template';
$lang['title_first_page'] = 'Ir para a primeira p&aacute;gina';
$lang['title_last_page'] = 'Ir para a &uacute;ltima p&aacute;gina';
$lang['title_manage_order'] = 'Gerir Pedido';
$lang['title_next_page'] = 'Ir para a pr&oacute;xima p&aacute;gina';
$lang['title_prev_page'] = 'Ir para a p&aacute;gina anterior';
$lang['title_useremail_template'] = 'Email Template para o User';
$lang['to'] = 'Para';
$lang['total'] = 'Total ';
$lang['tracking_num'] = 'N&uacute;mero de rastreamento';
$lang['update_status'] = 'Actualizar Estado';
$lang['unit_price'] = 'Valor &Uacute;nico';
$lang['unit_weight'] = 'Peso &Uacute;nico';
$lang['unlimited'] = 'Il&iacute;mitado';
$lang['username'] = 'Nome de Utilizador';
$lang['user_email_template'] = 'Email Template para o User';
$lang['view'] = 'Visualizar';
$lang['view_message'] = 'Ver Mensagens';
$lang['view_messages'] = 'Exibir Mensagens relativas a este pedido';
$lang['weight'] = 'Peso';
$lang['within'] = 'Dentro';
$lang['yes'] = 'Sim';
$lang['utma'] = '156861353.3475328182428258000.1235609324.1235780246.1235825140.6';
$lang['utmz'] = '156861353.1235747081.4.3.utmcsr=forum.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/index.php/topic,31172.0.html';
$lang['utmc'] = '156861353';
$lang['utmb'] = '156861353';
?>
